"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = exports.name = exports.NavigationContext = void 0;

var React = _interopRequireWildcard(require("react"));

var _classnames = _interopRequireDefault(require("classnames"));

var _styles = require("@fluent-ui/styles");

var _Navigation = require("./Navigation.styled");

var _Navigation2 = require("./Navigation.type");

var _hooks = require("@fluent-ui/hooks");

var _utils = require("../utils");

var _Header = _interopRequireDefault(require("./components/Header"));

var _Footer = _interopRequireDefault(require("./components/Footer"));

var _Content = _interopRequireDefault(require("./components/Content"));

var _Box = _interopRequireDefault(require("../Box"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

function _getRequireWildcardCache() { if (typeof WeakMap !== "function") return null; var cache = new WeakMap(); _getRequireWildcardCache = function _getRequireWildcardCache() { return cache; }; return cache; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } var cache = _getRequireWildcardCache(); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; if (obj != null) { var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj["default"] = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) { return; } var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var NavigationContext = React.createContext({
  value: '',
  onChange: function onChange() {},
  expanded: true,
  reveal: false,
  acrylic: false,
  horizontal: false
});
exports.NavigationContext = NavigationContext;
var name = 'Navigation';
exports.name = name;
var useStyles = (0, _styles.createUseStyles)(_Navigation.styles, {
  name: name
});
var Navigation = React.forwardRef(function (props, ref) {
  var _classNames;

  var _props$as = props.as,
      as = _props$as === void 0 ? 'div' : _props$as,
      classNameProp = props.className,
      _props$horizontal = props.horizontal,
      horizontal = _props$horizontal === void 0 ? false : _props$horizontal,
      _props$expanded = props.expanded,
      expanded = _props$expanded === void 0 ? true : _props$expanded,
      _props$acrylic = props.acrylic,
      acrylic = _props$acrylic === void 0 ? false : _props$acrylic,
      reveal = props.reveal,
      value = props.value,
      onChange = props.onChange,
      children = props.children,
      rest = _objectWithoutProperties(props, ["as", "className", "horizontal", "expanded", "acrylic", "reveal", "value", "onChange", "children"]);

  var container = {
    header: [],
    footer: [],
    content: []
  };
  React.Children.forEach(children, function (child) {
    if (child.type && child.type.displayName === 'FNavigationHeader') {
      container.header.push(child);
    } else if (child.type && child.type.displayName === 'FNavigationFooter') {
      container.footer.push(child);
    } else {
      container.content.push(child);
    }
  });

  var _reveal = acrylic ? false : reveal;

  var _useReveal = (0, _hooks.useReveal)(66),
      _useReveal2 = _slicedToArray(_useReveal, 1),
      RevealWrapper = _useReveal2[0];

  var revealHeader = React.useMemo(function () {
    return container.header.map(function (child, i) {
      return React.createElement(RevealWrapper, {
        key: i
      }, child);
    });
  }, [] // eslint-disable-line
  );
  var revealContent = React.useMemo(function () {
    return container.content.map(function (child, i) {
      if (child.type && child.type.displayName === 'FItem') {
        return React.createElement(RevealWrapper, {
          key: i
        }, child);
      }

      return child;
    });
  }, [] // eslint-disable-line
  );
  var revealFooter = React.useMemo(function () {
    return container.footer.map(function (child, i) {
      return React.createElement(RevealWrapper, {
        key: i
      }, child);
    });
  }, [] // eslint-disable-line
  );
  var contextValue = {
    value: value,
    onChange: onChange,
    expanded: expanded,
    reveal: _reveal,
    acrylic: acrylic,
    horizontal: horizontal
  };
  var others = (0, _utils.omit)(rest, ['backgroundColor', 'color']);
  var classes = useStyles(props);
  var className = (0, _classnames["default"])(classes.root, (_classNames = {}, _defineProperty(_classNames, classes.horizontal, horizontal), _defineProperty(_classNames, classes.expanded, expanded), _classNames), classNameProp);
  var headerClassName = (0, _classnames["default"])(classes.header, _defineProperty({}, classes.headerHorizontal, horizontal));
  var contentClassName = (0, _classnames["default"])(classes.content, _defineProperty({}, classes.contentHorizontal, horizontal));
  var footerClassName = (0, _classnames["default"])(classes.footer, _defineProperty({}, classes.footerHorizontal, horizontal));
  return React.createElement(_Box["default"], _extends({
    className: className,
    as: as,
    ref: ref,
    acrylic: acrylic,
    backgroundColor: "standard.light2"
  }, others), React.createElement(NavigationContext.Provider, {
    value: contextValue
  }, React.createElement(_Box["default"], {
    className: headerClassName
  }, _reveal ? revealHeader : container.header), React.createElement(_Box["default"], {
    className: contentClassName
  }, _reveal ? revealContent : container.content), React.createElement(_Box["default"], {
    className: footerClassName
  }, _reveal ? revealFooter : container.footer)));
});
Object.defineProperty(Navigation, 'Header', {
  get: function get() {
    return _Header["default"];
  }
});
Object.defineProperty(Navigation, 'Footer', {
  get: function get() {
    return _Footer["default"];
  }
});
Object.defineProperty(Navigation, 'Content', {
  get: function get() {
    return _Content["default"];
  }
});
Navigation.displayName = "F".concat(name);
Navigation.propTypes = _Navigation2.NavigationPropTypes;
Navigation.defaultProps = {
  horizontal: false,
  expanded: true,
  acrylic: false
};
var _default = Navigation;
exports["default"] = _default;