const wrapper = {
  display: 'inline-block',
  position: 'relative',
  minWidth: 160,
  font: 'inherit'
};

const root = theme => ({
  outline: 'none',
  font: 'inherit',
  width: '100%',
  borderRadius: 2,
  border: '2px solid',
  borderColor: theme.colors.standard.default,
  transition: theme.transitions.input,
  '&:hover': {
    borderColor: theme.colors.standard.dark1
  },
  '&:active, &:focus': {
    borderColor: theme.colors.primary.default
  },
  '&:disabled': {
    color: theme.colors.standard.dark2,
    backgroundColor: theme.colors.standard.light1,
    cursor: 'not-allowed',
    pointerEvents: 'none'
  },
  ...theme.sizes.medium.input,
  '&:not(:first-child)': {
    paddingLeft: 30
  },
  '&:not(:last-child)': {
    paddingRight: 30
  }
});

const error = theme => ({
  borderColor: theme.colors.error.default,
  '&:hover': {
    borderColor: theme.colors.error.default
  },
  '&:active, &:focus': {
    borderColor: theme.colors.error.default
  }
});

const clearedIcon = theme => ({
  height: '100%',
  position: 'absolute',
  right: 0,
  top: 0,
  fontSize: 12,
  cursor: 'pointer',
  display: 'inline-flex',
  justifyContent: 'center',
  alignItems: 'center',
  transition: theme.transitions.input,
  '&:hover': {
    backgroundColor: theme.colors.primary.default,
    color: theme.colors.white.default
  }
});

const extra = theme => ({
  position: 'absolute',
  top: '50%',
  transform: 'translateY(-50%)',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  color: theme.colors.standard.transparent3
});

const prefix = theme => ({ ...extra(theme),
  left: 12
});

const suffix = theme => props => ({ ...extra(theme),
  right: 12 + (props.suffix && !!props.value ? 30 : 0)
});

const ghost = theme => ({
  backgroundColor: 'transparent',
  borderColor: theme.colors.standard.transparent1,
  '&:hover': {
    borderColor: theme.colors.standard.transparent2
  },
  '&:active, &:focus': {
    borderColor: theme.colors.standard.transparent3
  }
});

export const styles = theme => ({
  root: root(theme),
  error: error(theme),
  wrapper,
  clearedIcon: clearedIcon(theme),
  prefix: prefix(theme),
  suffix: suffix(theme),
  ghost: ghost(theme)
});