import * as React from 'react';
import * as PropTypes from 'prop-types';
import { BoxProps } from '../Box';
import Header from './components/Header';
import Footer from './components/Footer';
import Content from './components/Content';
export declare type NavigationClassProps = 'root' | 'horizontal' | 'expanded' | 'header' | 'headerHorizontal' | 'footer' | 'footerHorizontal' | 'content' | 'contentHorizontal';
export declare type NavigationID = string | number;
export interface NavigationProps extends Omit<BoxProps, 'onChange'> {
    horizontal?: boolean;
    response?: boolean;
    expanded?: boolean;
    acrylic?: boolean;
    reveal?: boolean;
    value?: NavigationID;
    onChange?: (id: NavigationID) => void;
}
export interface NavigationType extends React.ForwardRefExoticComponent<NavigationProps & React.RefAttributes<HTMLDivElement>> {
    Header: typeof Header;
    Footer: typeof Footer;
    Content: typeof Content;
}
export interface NavigationContainer {
    header: React.ReactComponentElement<typeof Header>[];
    footer: React.ReactComponentElement<typeof Footer>[];
    content: React.ReactComponentElement<typeof Content>[];
}
export declare type NavigationChild = React.ReactComponentElement<typeof Header> | React.ReactComponentElement<typeof Footer> | React.ReactComponentElement<typeof Content> | any;
export interface NavigationContentProps {
    children: React.ReactNode;
}
export interface NavigationHeaderProps {
    children: React.ReactNode;
}
export interface NavigationFooterProps {
    children: React.ReactNode;
}
export declare const NavigationPropTypes: {
    horizontal: PropTypes.Requireable<boolean>;
    response: PropTypes.Requireable<boolean>;
    expanded: PropTypes.Requireable<boolean>;
    acrylic: PropTypes.Requireable<boolean>;
    reveal: PropTypes.Requireable<boolean>;
    value: PropTypes.Requireable<string | number>;
    theme: PropTypes.Requireable<object>;
    children: PropTypes.Requireable<PropTypes.ReactNodeLike>;
    as: PropTypes.Requireable<"symbol" | "object" | "big" | "link" | "small" | "sub" | "sup" | "track" | "progress" | "a" | "abbr" | "address" | "area" | "article" | "aside" | "audio" | "b" | "base" | "bdi" | "bdo" | "blockquote" | "body" | "br" | "button" | "canvas" | "caption" | "cite" | "code" | "col" | "colgroup" | "data" | "datalist" | "dd" | "del" | "details" | "dfn" | "dialog" | "div" | "dl" | "dt" | "em" | "embed" | "fieldset" | "figcaption" | "figure" | "footer" | "form" | "h1" | "h2" | "h3" | "h4" | "h5" | "h6" | "head" | "header" | "hgroup" | "hr" | "html" | "i" | "iframe" | "img" | "input" | "ins" | "kbd" | "label" | "legend" | "li" | "main" | "map" | "mark" | "menu" | "meta" | "meter" | "nav" | "noscript" | "ol" | "optgroup" | "option" | "output" | "p" | "param" | "picture" | "pre" | "q" | "rp" | "rt" | "ruby" | "s" | "samp" | "script" | "section" | "select" | "source" | "span" | "strong" | "style" | "summary" | "table" | "tbody" | "td" | "template" | "textarea" | "tfoot" | "th" | "thead" | "time" | "title" | "tr" | "u" | "ul" | "var" | "video" | "wbr" | "circle" | "clipPath" | "defs" | "desc" | "ellipse" | "feBlend" | "feColorMatrix" | "feComponentTransfer" | "feComposite" | "feConvolveMatrix" | "feDiffuseLighting" | "feDisplacementMap" | "feDistantLight" | "feFlood" | "feFuncA" | "feFuncB" | "feFuncG" | "feFuncR" | "feGaussianBlur" | "feImage" | "feMerge" | "feMergeNode" | "feMorphology" | "feOffset" | "fePointLight" | "feSpecularLighting" | "feSpotLight" | "feTile" | "feTurbulence" | "filter" | "foreignObject" | "g" | "image" | "line" | "linearGradient" | "marker" | "mask" | "metadata" | "path" | "pattern" | "polygon" | "polyline" | "radialGradient" | "rect" | "stop" | "svg" | "switch" | "text" | "textPath" | "tspan" | "use" | "view" | "menuitem" | "keygen" | "noindex" | "webview" | "animate" | "animateMotion" | "animateTransform" | "feDropShadow" | "mpath">;
};
